"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const get_added_keys_from_objects_1 = require("./common/get-added-keys-from-objects");
const get_removed_keys_from_objects_1 = require("./common/get-removed-keys-from-objects");
const create_difference_1 = require("./create-difference");
const findAddedDifferencesInHeaders = (sourceResponseHeaders, destinationResponseHeaders) => {
    const addedHeaders = get_added_keys_from_objects_1.getAddedKeysFromObjects(sourceResponseHeaders, destinationResponseHeaders);
    return addedHeaders.map((header) => {
        const addedHeader = destinationResponseHeaders[header];
        return create_difference_1.createDifference({
            action: 'add',
            destinationSpecOrigins: [addedHeader.originalValue],
            propertyName: 'response.header',
            source: 'openapi-diff',
            sourceSpecOrigins: []
        });
    });
};
const findRemovedDifferencesInHeaders = (sourceResponseHeaders, destinationResponseHeaders) => {
    const removedHeaders = get_removed_keys_from_objects_1.getRemovedKeysFromObjects(sourceResponseHeaders, destinationResponseHeaders);
    return removedHeaders.map((header) => {
        const removedHeader = sourceResponseHeaders[header];
        return create_difference_1.createDifference({
            action: 'remove',
            destinationSpecOrigins: [],
            propertyName: 'response.header',
            source: 'openapi-diff',
            sourceSpecOrigins: [removedHeader.originalValue]
        });
    });
};
const normalizeHeaders = (responseHeaders) => {
    return Object.keys(responseHeaders).reduce((accumulator, header) => {
        const lowerCaseHeaderKey = header.toLowerCase();
        accumulator[lowerCaseHeaderKey] = responseHeaders[header];
        return accumulator;
    }, {});
};
exports.findDifferencesInResponseHeaders = (sourceResponseHeaders, destinationResponseHeaders) => {
    const normalizedSourceResponseHeaders = normalizeHeaders(sourceResponseHeaders);
    const normalizedDestinationResponseHeaders = normalizeHeaders(destinationResponseHeaders);
    const addedDifferences = findAddedDifferencesInHeaders(normalizedSourceResponseHeaders, normalizedDestinationResponseHeaders);
    const removedDifferences = findRemovedDifferencesInHeaders(normalizedSourceResponseHeaders, normalizedDestinationResponseHeaders);
    return [...addedDifferences, ...removedDifferences];
};
