"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const create_difference_1 = require("./create-difference");
const defaultJsonSchemaDetails = () => ({
    isDefinedInOrigin: false,
    path: []
});
const toJsonSchemaDetails = (parsedScope) => {
    return parsedScope.jsonSchema === undefined
        ? defaultJsonSchemaDetails()
        : {
            isDefinedInOrigin: true,
            path: parsedScope.jsonSchema.originalPath
        };
};
const createSpecOrigin = (rootPathInSpec, differenceValue) => {
    return {
        originalPath: [...rootPathInSpec, ...differenceValue.path],
        value: differenceValue.value
    };
};
const createSpecOrigins = (parsedScope, differenceValues) => {
    const jsonSchemaDetails = toJsonSchemaDetails(parsedScope);
    return jsonSchemaDetails.isDefinedInOrigin
        ? differenceValues.map((differenceValue) => createSpecOrigin(jsonSchemaDetails.path, differenceValue))
        : [];
};
const createScopeDifference = (options) => {
    const destinationSpecOrigins = createSpecOrigins(options.destinationParsedScope, options.jsonSchemaDifference.destinationValues);
    const sourceSpecOrigins = createSpecOrigins(options.sourceParsedScope, options.jsonSchemaDifference.sourceValues);
    return create_difference_1.createDifference({
        action: options.action,
        destinationSpecOrigins,
        details: {
            value: options.jsonSchemaDifference.value
        },
        propertyName: options.propertyName,
        source: 'json-schema-diff',
        sourceSpecOrigins
    });
};
exports.getScopeAddDifferences = (options) => {
    const addedJsonSchemaDifferences = options.differences.filter((difference) => difference.addedByDestinationSchema);
    return addedJsonSchemaDifferences
        .map((jsonSchemaDifference) => createScopeDifference({
        action: 'add',
        destinationParsedScope: options.destinationScope,
        jsonSchemaDifference,
        propertyName: options.propertyName,
        sourceParsedScope: options.sourceScope
    }));
};
exports.getScopeRemoveDifferences = (options) => {
    const addedJsonSchemaDifferences = options.differences.filter((difference) => difference.removedByDestinationSchema);
    return addedJsonSchemaDifferences
        .map((jsonSchemaDifference) => createScopeDifference({
        action: 'remove',
        destinationParsedScope: options.destinationScope,
        jsonSchemaDifference,
        propertyName: options.propertyName,
        sourceParsedScope: options.sourceScope
    }));
};
